@@ -1,4 +1,4 @@
-# Copyright 2020 Google LLC
+# Copyright 2021 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,7 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Federated datasets for FedJAX."""
+"""fedjax datasets."""
 
+from fedjax.datasets import downloads
 from fedjax.datasets import emnist
-from fedjax.datasets import toy_regression
+from fedjax.datasets import shakespeare
+from fedjax.datasets import stackoverflow
+
