@@ -16,10 +16,6 @@
 from fedjax.training.checkpoint import load_latest_checkpoint
 from fedjax.training.checkpoint import save_checkpoint
 
-from fedjax.training.federated_experiment import ClientEvaluationFn
-from fedjax.training.federated_experiment import FederatedExperimentConfig
-from fedjax.training.federated_experiment import FullEvaluationFn
-from fedjax.training.federated_experiment import run_federated_experiment
 from fedjax.training.federated_experiment import set_tf_cpu_only
 
 from fedjax.training.logging import Logger
